mocksauth

package
v0.1.1 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 9, 2025 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MockAuthenticator

type MockAuthenticator struct {
	mock.Mock
}

MockAuthenticator is an autogenerated mock type for the Authenticator type

func NewMockAuthenticator

func NewMockAuthenticator(t interface {
	mock.TestingT
	Cleanup(func())
}) *MockAuthenticator

NewMockAuthenticator creates a new instance of MockAuthenticator. It also registers a testing interface on the mock and a cleanup function to assert the mocks expectations. The first argument is typically a *testing.T value.

func (*MockAuthenticator) DynamicAPI

func (_m *MockAuthenticator) DynamicAPI() (dynamic.Interface, error)

DynamicAPI provides a mock function with no fields

func (*MockAuthenticator) EXPECT

func (*MockAuthenticator) NativeAPI

func (_m *MockAuthenticator) NativeAPI() (kubernetes.Interface, error)

NativeAPI provides a mock function with no fields

type MockAuthenticator_DynamicAPI_Call

type MockAuthenticator_DynamicAPI_Call struct {
	*mock.Call
}

MockAuthenticator_DynamicAPI_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'DynamicAPI'

func (*MockAuthenticator_DynamicAPI_Call) Return

func (*MockAuthenticator_DynamicAPI_Call) Run

func (*MockAuthenticator_DynamicAPI_Call) RunAndReturn

type MockAuthenticator_Expecter

type MockAuthenticator_Expecter struct {
	// contains filtered or unexported fields
}

func (*MockAuthenticator_Expecter) DynamicAPI

DynamicAPI is a helper method to define mock.On call

func (*MockAuthenticator_Expecter) NativeAPI

NativeAPI is a helper method to define mock.On call

type MockAuthenticator_NativeAPI_Call

type MockAuthenticator_NativeAPI_Call struct {
	*mock.Call
}

MockAuthenticator_NativeAPI_Call is a *mock.Call that shadows Run/Return methods with type explicit version for method 'NativeAPI'

func (*MockAuthenticator_NativeAPI_Call) Return

func (*MockAuthenticator_NativeAPI_Call) Run

func (*MockAuthenticator_NativeAPI_Call) RunAndReturn

Jump to